searchData={"items":[{"type":"task","title":"mix vnu.validate.css","doc":"Validates CSS files.\n\nIt expects a file or a list of files as an argument.\n\n```bash\n  mix vnu.validate.css [OPTIONS] FILE [FILE2 FILE3...]\n```\n\nSee `mix vnu.validate.html` for the list of options and other details.\n\nExamples\n```bash\nmix vnu.validate.css screen.css print.css\nmix vnu.validate.css --server-url http://localhost:8888 priv/static/**/*.css\n```","ref":"Mix.Tasks.Vnu.Validate.Css.html"},{"type":"task","title":"mix vnu.validate.html","doc":"Validates HTML files.\n\nIt expects a file or a list of files as an argument.\n\n```bash\n  mix vnu.validate.html [OPTIONS] FILE [FILE2 FILE3...]\n```","ref":"Mix.Tasks.Vnu.Validate.Html.html"},{"type":"task","title":"Options - mix vnu.validate.html","doc":"- `--server-url` - The URL of the Checker server. Defaults to `http://localhost:8888`.\n- `--fail-on-warnings` -  Messages of type `:info` and subtype `:warning` will be treated as if they were validation errors.\n  Their presence will mean the document is invalid. Defaults to `false`.\n- `--filter` - A module implementing the `Vnu.MessageFilter` behavior that will be used to exclude messages matching the filter from the result.\n  Defaults to `nil` (no excluded messages).\n- `--http-client` - A module implementing the `Vnu.HTTPClient` behaviour that will be used to make the HTTP request to the server.\nDefaults to `Vnu.HTTPClient.Hackney`.","ref":"Mix.Tasks.Vnu.Validate.Html.html#module-options"},{"type":"task","title":"Exit code - mix vnu.validate.html","doc":"If validation of all files finished and no errors were found, the task will exit with code `0`.\nIf the validation of at least one file did not finish for any reason, or resulted in validation errors, the task will exit with code `1`.\n\nExamples\n\n```bash\nmix vnu.validate.html index.html about.html\nmix vnu.validate.html --server-url http://localhost:8888 priv/static/**/*.html\nmix vnu.validate.html --filter MyApp.VnuMessageFilter priv/static/**/*.html\n```","ref":"Mix.Tasks.Vnu.Validate.Html.html#module-exit-code"},{"type":"task","title":"mix vnu.validate.svg","doc":"Validates SVG files.\n\nIt expects a file or a list of files as an argument.\n\n```bash\n  mix vnu.validate.svg [OPTIONS] FILE [FILE2 FILE3...]\n```\n\nSee `mix vnu.validate.html` for the list of options and other details.\n\nExamples\n\n```bash\nmix vnu.validate.svg home_icon.svg logo.svg\nmix vnu.validate.svg --server-url http://localhost:8888 priv/static/**/*.svg\n```","ref":"Mix.Tasks.Vnu.Validate.Svg.html"},{"type":"module","title":"Vnu","doc":"General purpose validation functions for HTML, CSS, and SVG documents.","ref":"Vnu.html"},{"type":"function","title":"Vnu.valid?/2","doc":"Checks if the results of `Vnu.validate_html/2`, `Vnu.validate_css/2`, or `Vnu.validate_svg/2` determined the document to be valid.","ref":"Vnu.html#valid?/2"},{"type":"function","title":"Options - Vnu.valid?/2","doc":"- `:server_url` - The URL of [the Checker server](https://github.com/validator/validator). Defaults to `http://localhost:8888`.\n- `:fail_on_warnings` - Messages of type `:info` and subtype `:warning` will be treated as if they were validation errors.\n  Their presence will mean the document is invalid. Defaults to `false`.\n- `:http_client` - A module implementing the `Vnu.HTTPClient` behaviour that will be used to make the HTTP request to the server.\nDefaults to `Vnu.HTTPClient.Hackney`.","ref":"Vnu.html#valid?/2-options"},{"type":"function","title":"Examples - Vnu.valid?/2","doc":"iex> {:ok, result} = Vnu.validate_html(\"\", server_url: System.get_env(\"VNU_SERVER_URL\") || \"http://localhost:8888\")\n    iex> Vnu.valid?(result)\n    false\n\n    iex> {:ok, result} = Vnu.validate_html(~S(\n    ...><!DOCTYPE html>\n    ...> \n    ...> \n    ...>   \n    ...>   Hello World \n    ...> \n    ...> \n    ...> \n    ...> \n    ...>), server_url: System.get_env(\"VNU_SERVER_URL\") || \"http://localhost:8888\")\n    iex> [message] = result.messages\n    iex> message.message\n    \"Consider adding a “lang” attribute to the “html” start tag to declare the language of this document.\"\n    iex> message.sub_type\n    :warning\n    iex> Vnu.valid?(result)\n    true\n    iex> Vnu.valid?(result, fail_on_warnings: true)\n    false","ref":"Vnu.html#valid?/2-examples"},{"type":"function","title":"Vnu.validate_css/2","doc":"Validates the given CSS document.\n\nSee `validate_html/2` for the list of options and other details.","ref":"Vnu.html#validate_css/2"},{"type":"function","title":"Examples - Vnu.validate_css/2","doc":"iex> Vnu.validate_css(\".button { display: banana; }\", server_url: System.get_env(\"VNU_SERVER_URL\") || \"http://localhost:8888\")\n    {:ok, %Vnu.Result{messages: [\n      %Vnu.Message{\n        type: :error,\n        message: \"“display”: “banana” is not a “display” value.\",\n        extract: \".button { display: banana; }\\n\",\n        first_line: 1,\n        last_line: 1,\n        first_column: 20,\n        last_column: 25,\n        hilite_length: 6,\n        hilite_start: 19,\n      }\n    ]}}\n\n    iex> Vnu.validate_css(\"\", server_url: \"http://wrong-domain\")\n    {:error, %Vnu.Error{\n      reason: :unexpected_server_response,\n      message: \"Could not contact the server, got error: :nxdomain\"\n    }}","ref":"Vnu.html#validate_css/2-examples"},{"type":"function","title":"Vnu.validate_css!/2","doc":"Same as `validate_css/2` but returns `%Vnu.Result{}` or raises `%Vnu.Error{}`.","ref":"Vnu.html#validate_css!/2"},{"type":"function","title":"Vnu.validate_html/2","doc":"Validates the given HTML document.\n\nReturns `{:ok, %Vnu.Result{}}` if the validation process finished successfully, and `{:error, %Vnu.Error{}}` otherwise.\nNote that the `{:ok, %Vnu.Result{}}` return value does not mean necessarily that the document is valid.\nSee `Vnu.valid?/1` and `Vnu.Message` for interpreting the result.","ref":"Vnu.html#validate_html/2"},{"type":"function","title":"Options - Vnu.validate_html/2","doc":"- `:server_url` - The URL of [the Checker server](https://github.com/validator/validator).\nDefaults to `http://localhost:8888`.\n- `:filter` - A module implementing the `Vnu.MessageFilter` behavior that will be used to exclude messages matching the filter from the result.\nDefaults to `nil` (no excluded messages).\n- `:http_client` - A module implementing the `Vnu.HTTPClient` behaviour that will be used to make the HTTP request to the server.\nDefaults to `Vnu.HTTPClient.Hackney`.","ref":"Vnu.html#validate_html/2-options"},{"type":"function","title":"Examples - Vnu.validate_html/2","doc":"iex> Vnu.validate_html(~S(\n    ...><!DOCTYPE html>\n    ...> \n    ...> \n    ...>   \n    ...> \n    ...> \n    ...> \n    ...> \n    ...>), server_url: System.get_env(\"VNU_SERVER_URL\") || \"http://localhost:8888\")\n    {:ok, %Vnu.Result{messages: [\n      %Vnu.Message{\n        type: :error,\n        message: \"Element “head” is missing a required instance of child element “title”.\",\n        extract: \"=\\\"utf-8\\\">\\n \\n \\n \\n  Vnu.validate_html(\"\", server_url: \"http://wrong-domain\")\n    {:error, %Vnu.Error{\n      reason: :unexpected_server_response,\n      message: \"Could not contact the server, got error: :nxdomain\"\n    }}","ref":"Vnu.html#validate_html/2-examples"},{"type":"function","title":"Vnu.validate_html!/2","doc":"Same as `validate_svg/2` but returns `%Vnu.Result{}` or raises `%Vnu.Error{}`.","ref":"Vnu.html#validate_html!/2"},{"type":"function","title":"Vnu.validate_svg/2","doc":"Validates the given SVG document.\n\nSee `validate_html/2` for the list of options and other details.","ref":"Vnu.html#validate_svg/2"},{"type":"function","title":"Examples - Vnu.validate_svg/2","doc":"iex> Vnu.validate_svg(~S(\n    ...> \n    ...> Rectangle \n    ...> \n    ...> \n    ...> ), server_url: System.get_env(\"VNU_SERVER_URL\") || \"http://localhost:8888\")\n    {:ok, %Vnu.Result{messages: [\n      %Vnu.Message{\n        type: :info,\n        message: \"Using the preset for SVG 1.1 + URL + HTML + MathML 3.0 based on the root namespace.\"\n      },\n      %Vnu.Message{\n        type: :error,\n        message: \"SVG element “rect” is missing required attribute “width”.\",\n        extract: \"le \\n \\n  Vnu.validate_svg(\"\", server_url: \"http://wrong-domain\")\n    {:error, %Vnu.Error{\n      reason: :unexpected_server_response,\n      message: \"Could not contact the server, got error: :nxdomain\"\n    }}","ref":"Vnu.html#validate_svg/2-examples"},{"type":"function","title":"Vnu.validate_svg!/2","doc":"Same as `validate_svg/2` but returns `%Vnu.Result{}` or raises `%Vnu.Error{}`.","ref":"Vnu.html#validate_svg!/2"},{"type":"module","title":"Vnu.Assertions","doc":"ExUnit assertions for checking the validity of HTML, CSS, and SVG documents.","ref":"Vnu.Assertions.html"},{"type":"function","title":"Vnu.Assertions.assert_valid_css/2","doc":"Asserts that the given CSS document is valid.\n\nSee `assert_valid_html/2` for the list of options and other details.","ref":"Vnu.Assertions.html#assert_valid_css/2"},{"type":"function","title":"Vnu.Assertions.assert_valid_html/2","doc":"Asserts that the given HTML document is valid.","ref":"Vnu.Assertions.html#assert_valid_html/2"},{"type":"function","title":"Options - Vnu.Assertions.assert_valid_html/2","doc":"- `:server_url` - The URL of [the Checker server](https://github.com/validator/validator). Defaults to `http://localhost:8888`.\n- `:fail_on_warnings` - Messages of type `:info` and subtype `:warning` will be treated as if they were validation errors.\n  Their presence will mean the document is invalid. Defaults to `false`.\n- `:filter` - A module implementing the `Vnu.MessageFilter` behavior that will be used to exclude messages matching the filter from the result.\n  Defaults to `nil` (no excluded messages).\n- `:http_client` - A module implementing the `Vnu.HTTPClient` behaviour that will be used to make the HTTP request to the server.\n  Defaults to `Vnu.HTTPClient.Hackney`.\n- `:message_print_limit` - The maximum number of validation messages that will me printed in the error when the assertion fails.\n  Can be an integer or `:infinity`. Defaults to `:infinity`.","ref":"Vnu.Assertions.html#assert_valid_html/2-options"},{"type":"function","title":"Vnu.Assertions.assert_valid_svg/2","doc":"Asserts that the given SVG document is valid.\n\nSee `assert_valid_html/2` for the list of options and other details.","ref":"Vnu.Assertions.html#assert_valid_svg/2"},{"type":"behaviour","title":"Vnu.HTTPClient","doc":"Specification for a Vnu HTTP client.","ref":"Vnu.HTTPClient.html"},{"type":"callback","title":"Vnu.HTTPClient.post/3","doc":"A callback to make a POST HTTP request.","ref":"Vnu.HTTPClient.html#c:post/3"},{"type":"type","title":"Vnu.HTTPClient.body/0","doc":"","ref":"Vnu.HTTPClient.html#t:body/0"},{"type":"type","title":"Vnu.HTTPClient.header/0","doc":"","ref":"Vnu.HTTPClient.html#t:header/0"},{"type":"type","title":"Vnu.HTTPClient.response/0","doc":"","ref":"Vnu.HTTPClient.html#t:response/0"},{"type":"type","title":"Vnu.HTTPClient.status/0","doc":"","ref":"Vnu.HTTPClient.html#t:status/0"},{"type":"type","title":"Vnu.HTTPClient.url/0","doc":"","ref":"Vnu.HTTPClient.html#t:url/0"},{"type":"module","title":"Vnu.HTTPClient.Hackney","doc":"Hackney-based HTTP client adapter.","ref":"Vnu.HTTPClient.Hackney.html"},{"type":"module","title":"Vnu.Message","doc":"A message is a unit of information returned by the Checker.\nSee [its documentation](https://github.com/validator/validator/wiki/Output-%C2%BB-JSON#media-type) for detailed up to date information about its output format.","ref":"Vnu.Message.html"},{"type":"module","title":"Fields - Vnu.Message","doc":"- `:type` - One of `:error`, `:info`, or `:non_document_error`. Info messages can either be general information or warnings, see `:sub_type`.\n    Non-document errors signify errors with the Checker server itself, and are treated internally by this library as if the validation could not be run at all.\n- `:sub_type` - For messages of type `:error` it could be  `nil` or `:fatal`. For messages of type `:info`, it could be `nil` or `:warning`.\n- `:message` - The detailed description of the issue.\n- `:extract` - The snippet of the document that the message is about.\n-  `:first_line`, `:last_line`, `:first_column`, `:last_column` - The position of the part of the document the message is about relative to the whole document.\n    Lines and columns are numbered from 1.\n- `:hilite_start`, `:hilite_length` - Indicate the start and length of substring of the `:extract` that the message is roughly about.\n    The characters are numbered from 0.","ref":"Vnu.Message.html#module-fields"},{"type":"type","title":"Vnu.Message.t/0","doc":"","ref":"Vnu.Message.html#t:t/0"},{"type":"behaviour","title":"Vnu.MessageFilter","doc":"A behavior for excluding certain messages from the validation result.\n\nModules implementing this behavior can be passed as a `:filter` option to:\n- `Vnu.validate_html/2`, `Vnu.validate_css/2`, `Vnu.validate_svg/2`\n- `Vnu.Assertions.assert_valid_html/2`, `Vnu.Assertions.assert_valid_css/2`. `Vnu.Assertions.assert_valid_svg/2`","ref":"Vnu.MessageFilter.html"},{"type":"behaviour","title":"Example - Vnu.MessageFilter","doc":"```\ndefmodule MyApp.VnuMessageFilter do\n  @behaviour Vnu.MessageFilter\n\n  @impl Vnu.MessageFilter\n  def exclude_message?(%Vnu.Message{message: message}) do\n    # those errors are caused by the CSRF meta tag (`csrf_meta_tag()`)\n    # present in the layout of a newly-generated Phoenix app\n    patterns_to_ignore = [\n      ~r/A document must not include more than one “meta” element with a “charset” attribute./,\n      ~r/Attribute “(.)*” not allowed on element “meta” at this point./\n    ]\n\n    Enum.any?(patterns_to_ignore, &Regex.match?(&1, message))\n  end\nend\n```","ref":"Vnu.MessageFilter.html#module-example"},{"type":"callback","title":"Vnu.MessageFilter.exclude_message?/1","doc":"","ref":"Vnu.MessageFilter.html#c:exclude_message?/1"},{"type":"module","title":"Vnu.Result","doc":"A result holds a list of messages returned by the Checker for a given document.","ref":"Vnu.Result.html"},{"type":"type","title":"Vnu.Result.t/0","doc":"","ref":"Vnu.Result.html#t:t/0"},{"type":"exception","title":"Vnu.Error","doc":"An error holds details about why validating a given document could not be finished.","ref":"Vnu.Error.html"},{"type":"type","title":"Vnu.Error.t/0","doc":"","ref":"Vnu.Error.html#t:t/0"},{"type":"extras","title":"Overview","doc":"# Overview\n\n[![angelikatyborska](https://circleci.com/gh/angelikatyborska/vnu-elixir.svg?style=shield)](https://circleci.com/gh/angelikatyborska/vnu-elixir)\n![Hex.pm](https://img.shields.io/hexpm/v/vnu)\n![Hex.pm](https://img.shields.io/hexpm/dt/vnu)\n![Hex.pm](https://img.shields.io/hexpm/l/vnu)\n[![Coverage Status](https://coveralls.io/repos/github/angelikatyborska/vnu-elixir/badge.svg?branch=master)](https://coveralls.io/github/angelikatyborska/vnu-elixir?branch=master)\n\nAn Elixir client for [the Nu HTML Checker (v.Nu)](https://validator.w3.org/nu/).\n\n![Expected HTML document to be valid, but got 1 error. Attribute html-is-awesome not allowed on element body at this point.](https://raw.github.com/angelikatyborska/vnu-elixir/main/assets/overview.png)\n\n[v.Nu](https://validator.w3.org/nu/) is a document validity checker used by the W3C.\nIt offers validating HTML, CSS, and SVG documents.\n\nThis library brings that functionality to Elixir by using the Checker's JSON API.\nIt offers ExUnit assertions for validating dynamic content in tests, Mix tasks for validating static content, and general purpose functions to fulfill other needs.","ref":"overview.html"},{"type":"extras","title":"Installation","doc":"# Installation","ref":"installation.html"},{"type":"extras","title":"Prerequisites - Installation","doc":"While it is possible to use this library with the service run by W3C at [validator.w3.org/nu](https://validator.w3.org/nu/),\nI would recommend running your own instance. You will eliminate a lot of network latency if it runs on the same machine as your code, and you will not hit any rate limits that might exist for [validator.w3.org/nu](https://validator.w3.org/nu/).\n\nThe source of the Checker can be found in the repository [validator/validator](https://github.com/validator/validator).\nFollow their instructions on how to download it and [run it as a web server](https://github.com/validator/validator#standalone-web-server).\n\nThe easiest option is to use the Docker image, like this:\n```bash\ndocker run -it --rm -p 8888:8888 ghcr.io/validator/validator:latest\n```\n\nThe command might require an additional `--platform linux/amd64` flag on M1 macs.\n\nCheck if the server is running:\n```bash\n$ curl localhost:8888 -I\nHTTP/1.1 200 OK\n```","ref":"installation.html#prerequisites"},{"type":"extras","title":"Installation - Installation","doc":"Make sure to read about the [prerequisites](#prerequisites) first.\n\nAdd Vnu as a dependency to your project's `mix.exs`. To use the built-in, Hackney-based HTTP client adapter, also add `:hackney`:\n\n```elixir\ndefp deps do\n  [\n    {:vnu, \"~> 1.1\", only: [:dev, :test], runtime: false},\n    {:hackney, \"~> 1.18\"}\n  ]\nend\n```\n\nAnd run:\n\n```bash\n$ mix deps.get\n```\n\nIf you don't want to use Hackney, you can implement your own HTTP client module using the `Vnu.HTTPClient` behavior and pass it in the `http_client` option.","ref":"installation.html#installation"},{"type":"extras","title":"Usage","doc":"# Usage\n\nThere are 3 different ways of using this library:\n- [ExUnit assertions](#exunit-assertions),\n- [mix tasks for your static assets](#mix-tasks),\n- or [generic function calls for all other needs](#other-needs).","ref":"usage.html"},{"type":"extras","title":"ExUnit assertions - Usage","doc":"If you are building an application that generates HTML, CSS, or SVG files, you might want to use those validations in your tests.\n\n- `Vnu.Assertions.assert_valid_html/2`\n- `Vnu.Assertions.assert_valid_css/2`\n- `Vnu.Assertions.assert_valid_svg/2`\n\n#","ref":"usage.html#exunit-assertions"},{"type":"extras","title":"Phoenix example - Usage","doc":"I would recommend defining a local `assert_valid_html` function in your [`ConnCase`](https://hexdocs.pm/phoenix/testing.html#the-conncase) to have a single place to pass your default options.\n\n```elixir\ndefmodule PhoenixAppWeb.ConnCase do\n  use ExUnit.CaseTemplate\n\n  using do\n    quote do\n      # ...\n      def assert_valid_html(html, vnu_opts \\\\ []) do\n        default_vnu_opts = [\n          server_url: \"http://localhost:8888/\",\n          filter: PhoenixAppWeb.VnuHTMLMessageFilter,\n          fail_on_warnings: true\n        ]\n\n        Vnu.Assertions.assert_valid_html(html, Keyword.merge(default_vnu_opts, vnu_opts))\n      end\n    end\n  end\nend\n```\n\nThen, you can use this function in your controller tests, LiveView tests, and integration tests.\n\n##","ref":"usage.html#phoenix-example"},{"type":"extras","title":"Controller tests - Usage","doc":"```elixir\ndefmodule PhoenixAppWeb.PageControllerTest do\n  use PhoenixAppWeb.ConnCase\n\n  test \"GET /\", %{conn: conn} do\n    conn = get(conn, \"/\")\n\n    html_response =\n      conn\n      |> html_response(200)\n      |> assert_valid_html()\n\n    assert html_response =~ \"Peace of mind from prototype to production\"\n  end\nend\n```\n\n![](https://raw.github.com/angelikatyborska/vnu-elixir/main/assets/controller_test.png)\n\n##","ref":"usage.html#controller-tests"},{"type":"extras","title":"LiveView tests - Usage","doc":"The LiveView test function `Phoenix.LiveViewTest.html#live/2` returns the view's HTML without a doctype. This makes it necessary to create another helper function that will prepend the right doctype to the HTML before sending it to the validator.\n\n```elixir\ndefmodule PhoenixAppWeb.ConnCase do\n  use ExUnit.CaseTemplate\n\n  using do\n    quote do\n      # ...\n      def assert_valid_html_without_doctype(html, vnu_opts \\\\ []) do\n        assert_valid_html(\"<!DOCTYPE html>\\n#{html}\", vnu_opts)\n      end\n    end\n  end\nend\n```\n\n```elixir\ntest \"/live disconnected and connected mount\", %{conn: conn} do\n  conn = get(conn, ~p\"/live\")\n  \n  conn\n  |> html_response(200)\n  |> assert_valid_html()\n  \n  {:ok, _index_live, html} = live(conn)\n  \n  assert_valid_html_without_doctype(html)\nend\n```\n\nAt the moment, LiveView does not offer a public API to get the updated full page HTML after the initial render. This makes it impossible to assert whether the HTML is still valid after updates because [the Nu HTML Checker (v.Nu)](https://validator.w3.org/nu/) doesn't offer validating HTML fragments, only full documents.\n\n##","ref":"usage.html#liveview-tests"},{"type":"extras","title":"Hound integration tests - Usage","doc":"If you're using [Hound](https://hexdocs.pm/hound/) for your integration tests, you can call [`page_source`](https://hexdocs.pm/hound/Hound.Helpers.Page.html#page_source/0) and use HTML validations in our integration tests too.\n\n```elixir\nassert_valid_html_without_doctype(page_source())\n```","ref":"usage.html#hound-integration-tests"},{"type":"extras","title":"Mix tasks - Usage","doc":"If you have static HTML, CSS, or SVG files in your project, you might want to validate them with those mix tasks:\n\n- `mix vnu.validate.html`\n- `mix vnu.validate.css`\n- `mix vnu.validate.svg`\n\n#","ref":"usage.html#mix-tasks"},{"type":"extras","title":"Example - Usage","doc":"```bash\n$ mix vnu.validate.css --server-url http://localhost:8888 assets/**/*.css\n```\n\n![](https://raw.github.com/angelikatyborska/vnu-elixir/main/assets/mix_task.png)","ref":"usage.html#example"},{"type":"extras","title":"Other needs - Usage","doc":"If you need HTML, CSS, or SVG validation for something else, try one of those functions:\n\n- `Vnu.validate_html/2`\n- `Vnu.validate_css/2`\n- `Vnu.validate_svg/2`\n\n#","ref":"usage.html#other-needs"},{"type":"extras","title":"Example - Usage","doc":"```elixir\niex> {:ok, result} = Vnu.validate_html(\"<!DOCTYPE html>    \",\n  server_url: \"http://localhost:8888\")\n{:ok,\n %Vnu.Result{\n   messages: [\n     %Vnu.Message{\n       extract: \"tml>     \",\n       first_column: 16,\n       first_line: 1,\n       hilite_length: 6,\n       hilite_start: 10,\n       last_column: 21,\n       last_line: 1,\n       message: \"Consider adding a “lang” attribute to the “html” start tag to declare the language of this document.\",\n       offset: nil,\n       sub_type: :warning,\n       type: :info\n     }\n   ]\n }}\n\niex> Vnu.valid?(result)\nfalse\n```","ref":"usage.html#example"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.1.1 (2023-08-13) - Changelog","doc":"- Fix error in error message (sic) when hackney is missing\n- Documentation improvements; adding a LiveView example","ref":"changelog.html#1-1-1-2023-08-13"},{"type":"extras","title":"1.1.0 (2021-03-27) - Changelog","doc":"- Replace HTTPoison with hackney\n- Make hackney optional, allow passing a custom HTTPClient","ref":"changelog.html#1-1-0-2021-03-27"},{"type":"extras","title":"1.0.0 (2020-04-13) - Changelog","doc":"#","ref":"changelog.html#1-0-0-2020-04-13"},{"type":"extras","title":"Changed - Changelog","doc":"- When used incorrectly, instead of custom usage info, mix tasks will print the same message as running `mix help ...` would print\n- Lowered required `httpoison` and `jason` versions to `~> 1.0`","ref":"changelog.html#changed"},{"type":"extras","title":"1.0.0-rc.1 (2020-04-11) - Changelog","doc":"- Initial release candidate","ref":"changelog.html#1-0-0-rc-1-2020-04-11"}],"content_type":"text/markdown"}